==> apache-tinkerpop-3.5.5-src.zip: tinkerpop-3.5.5/gremlin-dotnet/test/Gremlin.Net.IntegrationTest/ConfigProvider.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System;
using System.IO;
using Microsoft.Extensions.Configuration;

namespace Gremlin.Net.IntegrationTest
{
    public static class ConfigProvider
    {
        static ConfigProvider()
        {
            Configuration = GetConfig();
        }

        public static IConfiguration Configuration { get; }

        private static IConfiguration GetConfig()
        {
            var configFile = Path.Combine(Directory.GetCurrentDirectory(), "appsettings.json");
            var builder = new ConfigurationBuilder()
                .AddJsonFile(configFile, false, false);

            IConfiguration config = builder.Build();
            if (Convert.ToBoolean(Environment.GetEnvironmentVariable("DOCKER_ENVIRONMENT")))
            {
                config["TestServerIpAddress"] = config["TestServerIpAddressDocker"];
            }

            return config;
        }
    }
}

==> apache-tinkerpop-3.8.0-src.zip: tinkerpop-3.8.0/gremlin-dotnet/test/Gremlin.Net.IntegrationTest/ConfigProvider.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System;
using System.IO;
using Microsoft.Extensions.Configuration;

namespace Gremlin.Net.IntegrationTest
{
    public static class ConfigProvider
    {
        static ConfigProvider()
        {
            Configuration = GetConfig();
        }

        public static IConfiguration Configuration { get; }

        private static IConfiguration GetConfig()
        {
            var configFile = Path.Combine(Directory.GetCurrentDirectory(), "appsettings.json");
            var builder = new ConfigurationBuilder()
                .AddJsonFile(configFile, false, false);

            IConfiguration config = builder.Build();
            if (Convert.ToBoolean(Environment.GetEnvironmentVariable("DOCKER_ENVIRONMENT")))
            {
                config["TestServerIpAddress"] = config["TestServerIpAddressDocker"];
                config["GremlinSocketServerIpAddress"] = config["GremlinSocketServerIpAddressDocker"];
                config["GremlinSocketServerConfig"] = config["GremlinSocketServerConfigDocker"];
            }

            return config;
        }
    }
}
